You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by de...@apache.org on 2005/06/22 13:14:01 UTC

svn commit: r191799 - in /webservices/axis/trunk/java/modules: addressing/ addressing/test-resources/ core/ core/src/org/apache/axis/clientapi/ core/src/org/apache/axis/deployment/ core/src/org/apache/axis/description/ core/src/org/apache/axis/phaseres...

Author: deepal
Date: Wed Jun 22 04:13:58 2005
New Revision: 191799

URL: http://svn.apache.org/viewcvs?rev=191799&view=rev
Log:
1. Added one more constructor to call to provide client side repository
2. got rid of the notion of server.xml/client.xml and intoduce axis2.xml as system configuration

Removed:
    webservices/axis/trunk/java/modules/addressing/test-resources/server.xml
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/client.xml
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/server.xml
    webservices/axis/trunk/java/modules/core/test-resources/deployment/BadConfigOrderChange/server.xml
    webservices/axis/trunk/java/modules/core/test-resources/deployment/SystemPhaseRemove/server.xml
    webservices/axis/trunk/java/modules/core/test-resources/deployment/server.xml
Modified:
    webservices/axis/trunk/java/modules/addressing/maven.xml
    webservices/axis/trunk/java/modules/core/maven.xml
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/clientapi/Call.java
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentConstants.java
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentEngine.java
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentParser.java
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/description/ModuleDescription.java
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseHolder.java
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseMetadata.java
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseResolver.java
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/AbstractTransportSender.java
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/AxisServlet.java
    webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/SimpleMailListener.java
    webservices/axis/trunk/java/modules/core/test-resources/deployment/BadServer.xml
    webservices/axis/trunk/java/modules/core/test-resources/deployment/server-transport.xml
    webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadModuleTest.java
    webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServerXMLTest.java
    webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/ModifiedConfigFileTest.java
    webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/SystemPhasesremovedTest.java
    webservices/axis/trunk/java/modules/wsdl/src/org/apache/axis/wsdl/WSDL2Code.java

Modified: webservices/axis/trunk/java/modules/addressing/maven.xml
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/addressing/maven.xml?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/addressing/maven.xml (original)
+++ webservices/axis/trunk/java/modules/addressing/maven.xml Wed Jun 22 04:13:58 2005
@@ -11,8 +11,8 @@
             <mkdir dir="target/classes/META-INF"/>
             <copy file="src/META-INF/module.xml"
 		tofile="target/classes/META-INF/module.xml"/>
-         <copy file="./test-resources/server.xml"
-		tofile="target/server.xml"/>
+         <copy file="./test-resources/axis2.xml"
+		tofile="target/axis2.xml"/>
         <mkdir dir="target/modules"/>
 	    <jar jarfile="target/addressing.mar" basedir="target/classes" >
 			<include name="**" />

Modified: webservices/axis/trunk/java/modules/core/maven.xml
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/maven.xml?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/maven.xml (original)
+++ webservices/axis/trunk/java/modules/core/maven.xml Wed Jun 22 04:13:58 2005
@@ -16,6 +16,6 @@
 		<ant:ant antfile="build.xml" inheritall="true" inheritrefs="true" dir="test-resources/deployment/module1"/>
             <ant:ant antfile="build.xml" inheritall="true" inheritrefs="true" dir="test-resources/deployment/serviceModule"/>
 	</j:jelly>
-      <ant:copy file="${basedir}/test-resources/deployment/server.xml" tofile="${basedir}/target/test-resources/deployment/server.xml"/>
+      <ant:copy file="${basedir}/test-resources/deployment/axis2.xml" tofile="${basedir}/target/test-resources/deployment/axis2.xml"/>
     </postGoal> 
  </project>

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/clientapi/Call.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/clientapi/Call.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/clientapi/Call.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/clientapi/Call.java Wed Jun 22 04:13:58 2005
@@ -35,16 +35,26 @@
  * This class is the pretty convineance class for the user without see the comlplexites of Axis2.
  */
 public class Call extends InOutMEPClient {
+
     private HashMap properties;
     private static OperationDescription opreationTemplate;
-
     /**
      * this is a convenience Class, here the Call will assume a Annoynmous Service.
      * @throws AxisFault
      */
 
     public Call() throws AxisFault {
-        super(assumeServiceContext());
+        super(assumeServiceContext(null));
+    }
+
+    /**
+     * This is used to create call object with client home , using onky this constructor it can
+     * able to engage modules  , addning client side parameters
+     * @param clientHome
+     * @throws AxisFault
+     */
+    public Call(String clientHome) throws AxisFault {
+      super(assumeServiceContext(clientHome));
     }
 
     /**
@@ -117,11 +127,11 @@
      * @return ServiceContext that has a ConfigurationContext set in and has assumed values.
      * @throws AxisFault
      */
-    private static ServiceContext assumeServiceContext() throws AxisFault {
+    private static ServiceContext assumeServiceContext(String clinetHome) throws AxisFault {
         ConfigurationContext sysContext = null;
         if (ListenerManager.configurationContext == null) {
             ConfigurationContextFactory efac = new ConfigurationContextFactory();
-            sysContext = efac.buildClientConfigurationContext(null);
+            sysContext = efac.buildClientConfigurationContext(clinetHome);
         }else{
             sysContext = ListenerManager.configurationContext;
         }

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentConstants.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentConstants.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentConstants.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentConstants.java Wed Jun 22 04:13:58 2005
@@ -47,8 +47,7 @@
     String JWS_EXTENSION = ".jws";
 
     String SERVICETAG = "service";
-    String SERVERST = "server";
-    String CLIENTST = "client" ;
+    String AXIS2CONFIG = "axisconfig";
 
     // for serviemetadat
     String PROVIDERNAME = "provider";

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentEngine.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentEngine.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentEngine.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentEngine.java Wed Jun 22 04:13:58 2005
@@ -118,7 +118,7 @@
      */
 
     public DeploymentEngine(String RepositaryName) throws DeploymentException {
-        this(RepositaryName, "server.xml");
+        this(RepositaryName, "axis2.xml");
     }
 
     public DeploymentEngine(String RepositaryName, String serverXMLFile) throws DeploymentException {
@@ -135,7 +135,7 @@
         File serverConf = new File(repository, serverXMLFile);
         if (!serverConf.exists()) {
             ClassLoader cl = Thread.currentThread().getContextClassLoader();
-            InputStream in = cl.getResourceAsStream("org/apache/axis/deployment/server.xml");
+            InputStream in = cl.getResourceAsStream("org/apache/axis/deployment/axis2.xml");
             if (in != null) {
                 try {
                     serverConf.createNewFile();
@@ -154,7 +154,7 @@
 
 
             } else {
-                throw new DeploymentException("can not found org/apache/axis/deployment/server.xml");
+                throw new DeploymentException("can not found org/apache/axis/deployment/axis2.xml");
 
             }
         }
@@ -198,14 +198,14 @@
 
     public AxisConfiguration load() throws DeploymentException {
         if (engineConfigName == null) {
-            throw new DeploymentException("path to Server.xml can not be NUll");
+            throw new DeploymentException("path to axis2.xml can not be NUll");
         }
         File tempfile = new File(engineConfigName);
         try {
             InputStream in = new FileInputStream(tempfile);
             axisConfig = createEngineConfig();
             DeploymentParser parser = new DeploymentParser(in, this);
-            parser.processGlobalConfig(((AxisConfigurationImpl) axisConfig), SERVERST);
+            parser.processGlobalConfig(((AxisConfigurationImpl) axisConfig), AXIS2CONFIG);
         } catch (FileNotFoundException e) {
             throw new DeploymentException("Exception at deployment", e);
         } catch (XMLStreamException e) {
@@ -243,12 +243,12 @@
             }
         } else {
             ClassLoader cl = Thread.currentThread().getContextClassLoader();
-            in = cl.getResourceAsStream("org/apache/axis/deployment/client.xml");
+            in = cl.getResourceAsStream("org/apache/axis/deployment/axis2.xml");
         }
         try {
             axisConfig = createEngineConfig();
             DeploymentParser parser = new DeploymentParser(in, this);
-            parser.processGlobalConfig(((AxisConfigurationImpl) axisConfig), CLIENTST);
+            parser.processGlobalConfig(((AxisConfigurationImpl) axisConfig), AXIS2CONFIG);
         } catch (XMLStreamException e) {
             throw new DeploymentException(e.getMessage());
         }
@@ -268,7 +268,7 @@
 
 
     private void checkClientHome(String clientHome) throws DeploymentException {
-        String clientXML = "client.xml";
+        String clientXML = "axis2.xml";
         this.folderName = clientHome;
         File repository = new File(clientHome);
         if (!repository.exists()) {
@@ -281,7 +281,7 @@
         File serverConf = new File(repository, clientXML);
         if (!serverConf.exists()) {
             ClassLoader cl = Thread.currentThread().getContextClassLoader();
-            InputStream in = cl.getResourceAsStream("org/apache/axis/deployment/client.xml");
+            InputStream in = cl.getResourceAsStream("org/apache/axis/deployment/axis2.xml");
             if (in != null) {
                 try {
                     serverConf.createNewFile();
@@ -300,7 +300,7 @@
 
 
             } else {
-                throw new DeploymentException("can not found org/apache/axis/deployment/client.xml");
+                throw new DeploymentException("can not found org/apache/axis/deployment/axis2.xml");
 
             }
         }
@@ -337,11 +337,11 @@
                     ((String) inPhases.get(2)).equals(PhaseMetadata.PHASE_DISPATCH) &&
                     ((String) inPhases.get(3)).equals(PhaseMetadata.PHASE_POST_DISPATCH))) {
                 throw new DeploymentException("Invalid System predefined inphases , phase order dose not" +
-                        " support\n recheck server.xml");
+                        " support\n recheck axis2.xml");
             }
         } catch (DeploymentException e) {
             throw new DeploymentException("Invalid System predefined inphases , phase order dose not" +
-                    " support\n recheck server.xml");
+                    " support\n recheck axis2.xml");
         }
         //  ArrayList outPhaes = tempdata.getOUTPhases();
         //TODO do the validation code here

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentParser.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentParser.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/description/ModuleDescription.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/description/ModuleDescription.java Wed Jun 22 04:13:58 2005
@@ -26,7 +26,7 @@
  * <li>parameters<li>
  * <li>handlers<li>
  * <ol>
- * <p>Handler are registered once they are avlible but they avalibe to all services if server.xml
+ * <p>Handler are registered once they are avlible but they avalibe to all services if axis2.xml
  * has a module ref="." or avalible to a single service if service.xml have module ref=".."</p>
  */
 public class ModuleDescription implements FlowInclude, ParameterInclude {

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseHolder.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseHolder.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseHolder.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseHolder.java Wed Jun 22 04:13:58 2005
@@ -67,7 +67,7 @@
             throw new PhaseException("Invalid Phase ," + phaseName
                     + "for the handler "
                     + handler.getName()
-                    + " dose not exit in server.xml or refering to phase in diffrent flow");
+                    + " dose not exit in axis2.xml or refering to phase in diffrent flow");
         }
     }
 

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseMetadata.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseMetadata.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseMetadata.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseMetadata.java Wed Jun 22 04:13:58 2005
@@ -42,7 +42,7 @@
     public static final String PHASE_TRANSPORT_OUT = "MessageOut";
     /**
      * todo  I think thi shas to be change
-     * All the handlers inside transportsender and TranportRecievre in server.xml gose
+     * All the handlers inside transportsender and TranportRecievre in axis2.xml gose
      * to this phase
      */
     public static final String TRANSPORT_PHASE = "TRANSPORT";

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseResolver.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseResolver.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/AbstractTransportSender.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/AbstractTransportSender.java Wed Jun 22 04:13:58 2005
@@ -65,7 +65,7 @@
      */
     public void invoke(MessageContext msgContext) throws AxisFault {
         //Check for the REST behaviour, if you desire rest beahaviour
-        //put a <parameter name="doREST" value="true"/> at the server.xml/client.xml file
+        //put a <parameter name="doREST" value="true"/> at the axis2.xml
         Object doREST = msgContext.getProperty(Constants.Configuration.DO_REST);
         if (doREST != null && Constants.VALUE_TRUE.equals(doREST)) {
             this.doREST = true;

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/AxisServlet.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/AxisServlet.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/AxisServlet.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/http/AxisServlet.java Wed Jun 22 04:13:58 2005
@@ -52,7 +52,6 @@
 import org.apache.axis.soap.SOAPFactory;
 import org.apache.axis.soap.impl.llom.builder.StAXSOAPModelBuilder;
 import org.apache.axis.soap.impl.llom.soap11.SOAP11Factory;
-import org.apache.axis.soap.impl.llom.SOAPProcessingException;
 import org.apache.axis.util.Utils;
 
 /**
@@ -207,7 +206,7 @@
                     new BufferedReader(new InputStreamReader(req.getInputStream())));
 
             //Check for the REST behaviour, if you desire rest beahaviour
-            //put a <parameter name="doREST" value="true"/> at the server.xml/client.xml file
+            //put a <parameter name="doREST" value="true"/> at the axis2.xml
             Object doREST = msgContext.getProperty(Constants.Configuration.DO_REST);
             StAXBuilder builder = null;
             SOAPEnvelope envelope = null;
@@ -229,8 +228,6 @@
         } catch (XMLStreamException e) {
             throw new ServletException(e);
         } catch (FactoryConfigurationError e) {
-            throw new ServletException(e);
-        } catch (SOAPProcessingException e) {
             throw new ServletException(e);
         }
     }

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/SimpleMailListener.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/SimpleMailListener.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/SimpleMailListener.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/mail/SimpleMailListener.java Wed Jun 22 04:13:58 2005
@@ -245,7 +245,7 @@
                 sas.start();
             } else {
                 System.out.println(
-                    "Startup failed, mail transport not configured, Configure the mail trnasport in the server.xml file");
+                    "Startup failed, mail transport not configured, Configure the mail trnasport in the axis2.xml file");
             }
         }
     }

Modified: webservices/axis/trunk/java/modules/core/test-resources/deployment/BadServer.xml
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test-resources/deployment/BadServer.xml?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test-resources/deployment/BadServer.xml (original)
+++ webservices/axis/trunk/java/modules/core/test-resources/deployment/BadServer.xml Wed Jun 22 04:13:58 2005
@@ -1,4 +1,4 @@
-<server name ="AxisJava2.0" >
+<axisconfig name ="AxisJava2.0" >
     <parameter name="para1" locked="xsd:true">10</parameter>
     <parameter name="para2" locked="xsd:false">Colombo</parameter>
     <handler name="h1" class="org.apache.axis.engine.registry.SpeakingHandler">
@@ -24,4 +24,4 @@
     <gool>
         not good
     </gool>
-</server>
\ No newline at end of file
+</axisconfig>
\ No newline at end of file

Modified: webservices/axis/trunk/java/modules/core/test-resources/deployment/server-transport.xml
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test-resources/deployment/server-transport.xml?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test-resources/deployment/server-transport.xml (original)
+++ webservices/axis/trunk/java/modules/core/test-resources/deployment/server-transport.xml Wed Jun 22 04:13:58 2005
@@ -1,4 +1,4 @@
-<server name="AxisJava2.0">
+<axisconfig name="AxisJava2.0">
     <messageReceiver mep="INOUT" class="org.apache.axis.receivers.RawXMLINOutMessageRecevier"/>
     <transportReceiver name="http">
         <parameter name="para1" locked="xsd:true">10</parameter>
@@ -30,5 +30,5 @@
         <!--      user can add his own phases to this area  -->
         <phase name="userphase1"/>
     </phaseOrder>
-</server>
+</axisconfig>
 

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadModuleTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadModuleTest.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadModuleTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadModuleTest.java Wed Jun 22 04:13:58 2005
@@ -36,7 +36,7 @@
             InputStream in = new FileInputStream(getTestResourceFile("deployment/Badmodule.xml"));
             DeploymentParser parser = new DeploymentParser(in, null);
             AxisConfigurationImpl glabl = new AxisConfigurationImpl();
-            parser.processGlobalConfig(glabl,DeploymentConstants.SERVERST);
+            parser.processGlobalConfig(glabl,DeploymentConstants.AXIS2CONFIG);
             fail("this must failed gracefully with DeploymentException or FileNotFoundException");
         } catch (FileNotFoundException e) {
             return;

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServerXMLTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServerXMLTest.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServerXMLTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/BadServerXMLTest.java Wed Jun 22 04:13:58 2005
@@ -36,7 +36,7 @@
             InputStream in = new FileInputStream(getTestResourceFile("deployment/BadServer.xml"));
             DeploymentParser parser = new DeploymentParser(in, null);
             AxisConfigurationImpl glabl = new AxisConfigurationImpl();
-            parser.processGlobalConfig(glabl,DeploymentConstants.SERVERST);
+            parser.processGlobalConfig(glabl,DeploymentConstants.AXIS2CONFIG);
             fail("this must failed gracefully with DeploymentException or FileNotFoundException");
         } catch (FileNotFoundException e) {
             return;

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/ModifiedConfigFileTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/ModifiedConfigFileTest.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/ModifiedConfigFileTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/ModifiedConfigFileTest.java Wed Jun 22 04:13:58 2005
@@ -41,7 +41,7 @@
             ConfigurationContextFactory builder = new ConfigurationContextFactory();
             er = builder.buildConfigurationContext(filename).getAxisConfiguration();
             fail("this must failed gracefully with DeploymentException \"Invalid System predefined " +
-                    "inphases , phase order dose not\" +\n support\\n recheck server.xml\"");
+                    "inphases , phase order dose not\" +\n support\\n recheck axis2.xml\"");
         } catch (DeploymentException e) {
             e.printStackTrace();
         }

Modified: webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/SystemPhasesremovedTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/SystemPhasesremovedTest.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/SystemPhasesremovedTest.java (original)
+++ webservices/axis/trunk/java/modules/core/test/org/apache/axis/deployment/SystemPhasesremovedTest.java Wed Jun 22 04:13:58 2005
@@ -37,7 +37,7 @@
                 ConfigurationContextFactory builder = new ConfigurationContextFactory();
                 er = builder.buildConfigurationContext(filename).getAxisConfiguration();
                 fail("this must failed gracefully with DeploymentException \"Invalid System predefined " +
-                        "inphases , phase order dose not\" +\n support\\n recheck server.xml\"");
+                        "inphases , phase order dose not\" +\n support\\n recheck axis2.xml\"");
             } catch (DeploymentException e) {
                 e.printStackTrace();
             }

Modified: webservices/axis/trunk/java/modules/wsdl/src/org/apache/axis/wsdl/WSDL2Code.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/wsdl/src/org/apache/axis/wsdl/WSDL2Code.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/wsdl/src/org/apache/axis/wsdl/WSDL2Code.java (original)
+++ webservices/axis/trunk/java/modules/wsdl/src/org/apache/axis/wsdl/WSDL2Code.java Wed Jun 22 04:13:58 2005
@@ -38,7 +38,7 @@
 		System.out.println("-l <language> : valid languages are java and csharp. Default is java");
 		System.out.println("-t : Generate TestCase to test the generated code");
 		System.out.println("-ss : Generate server side code (i.e. skeletons).Default is off");
-		System.out.println("-sd : Generate service descriptor (i.e. server.xml).Default is off.Valid with -ss ");
+		System.out.println("-sd : Generate service descriptor (i.e. axis2.xml).Default is off.Valid with -ss ");
 		System.exit(0);
 	}
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentParser.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/deployment/DeploymentParser.java Wed Jun 22 04:13:58 2005
@@ -36,7 +36,7 @@
 
 /**
  * This class is used to parse the following xml douments
- * 1 server.xml
+ * 1 axis2.xml
  * 2 service.xml
  * 3 module.xml
  * <p/>
@@ -93,7 +93,7 @@
     }
 
     /**
-     * To process server.xml
+     * To process axis2.xml
      */
     public void processGlobalConfig(AxisConfigurationImpl axisGlobal, String starttag)
             throws DeploymentException {
@@ -120,7 +120,7 @@
                         TransportInDescription transportin = proccessTrasnsportIN();
                         dpengine.getAxisConfig().addTransportIn(transportin);
                     } else if (TYPEMAPPINGST.equals(ST)) {
-                        throw new UnsupportedOperationException("Type Mappings are not allowed in server.xml");
+                        throw new UnsupportedOperationException("Type Mappings are not allowed in axis2.xml");
                     } else if (MESSAGERECEIVER.equals(ST)) {
                         int attribCount = pullparser.getAttributeCount();
                         if (attribCount == 2) {
@@ -154,14 +154,14 @@
                                     }
                                 } else
                                     throw new UnsupportedOperationException(
-                                            "invalid attributes in server.xml (messageReceiver elemet) "
+                                            "invalid attributes in axis2.xml (messageReceiver elemet) "
                                             + attname);
                             } else
                                 throw new UnsupportedOperationException(
-                                        "invalid attributes in server.xml (messageReceiver elemet) "
+                                        "invalid attributes in axis2.xml (messageReceiver elemet) "
                                         + attname);
                         } else
-                            throw new UnsupportedOperationException("invalid attributes in server.xml (messageReceiver elemet)");
+                            throw new UnsupportedOperationException("invalid attributes in axis2.xml (messageReceiver elemet)");
 
                     } else if (MODULEST.equals(ST)) {
                         int attribCount = pullparser.getAttributeCount();
@@ -202,7 +202,7 @@
                         }
                     } else {
                         throw new UnsupportedOperationException(
-                                ST + " element is not allowed in the server.xml");
+                                ST + " element is not allowed in the axis2.xml");
                     }
                 } else if (eventType == XMLStreamConstants.END_ELEMENT) {
                     String endtagname = pullparser.getLocalName();
@@ -562,7 +562,7 @@
     }
 
     /**
      * this method is to process the HandlerMetaData tag in the either service.xml or server.xml
      *
      * @return HandlerMetaData object
      * @throws org.apache.axis.deployment.DeploymentException
@@ -562,7 +562,7 @@
 
     /**
-     * this method is to process the HandlerMetaData tag in the either service.xml or server.xml
+     * this method is to process the HandlerMetaData tag in the either service.xml or axis2.xml
      *
      * @return HandlerMetaData object

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/description/ModuleDescription.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/description/ModuleDescription.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseResolver.java (original)
+++ webservices/axis/trunk/java/modules/core/src/org/apache/axis/phaseresolver/PhaseResolver.java Wed Jun 22 04:13:58 2005
@@ -107,7 +107,7 @@
         ModuleDescription module;
         Flow flow = null;
         ///////////////////////////////////////////////////////////////////////////////////////////
         ////////////////////////// Handlers from   server.xml from modules/////////////////////////
         ArrayList modulqnames = (ArrayList) ((AxisConfigurationImpl) axisConfig).getEngadgedModules();
         for (int i = 0; i < modulqnames.size(); i++) {
             QName modulename = (QName) modulqnames.get(i);
@@ -137,7 +137,7 @@
                 }
                 axisService.addToEngagModuleList(module);
             } else {
-                throw new PhaseException("referance to invalid module " + modulename.getLocalPart() + " by server.xml");
+                throw new PhaseException("referance to invalid module " + modulename.getLocalPart() + " by axis2.xml");
             }
 
             if (flow != null) {
@@ -383,7 +383,7 @@
                         }
                 }
                 ////////////////////////////////////////////////////////////////////////////////////
                 /////////////////// Modules refered by server.xml //////////////////////////////////
                 ////////////////////////////////////////////////////////////////////////////////////
                 switch (type) {
                     case PhaseMetadata.IN_FLOW:
@@ -449,7 +449,7 @@
                     }
             }
             ////////////////////////////////////////////////////////////////////////////////////
             /////////////////// Modules refered by server.xml //////////////////////////////////
             ////////////////////////////////////////////////////////////////////////////////////
             switch (type) {
                 case PhaseMetadata.IN_FLOW:
@@ -483,7 +483,7 @@
                          * These handlers will go to operation's handler chains , since the module
                          * try to add handlres to both sytem predefined phases and user defined phase
                          * so global module can do that. here the global module are the module which are
-                         * reffred by server.xml
+                         * reffred by axis2.xml
                          */
                         continue;
                     }
@@ -107,7 +107,7 @@
         Flow flow = null;
         ///////////////////////////////////////////////////////////////////////////////////////////
-        ////////////////////////// Handlers from   server.xml from modules/////////////////////////
+        ////////////////////////// Handlers from   axis2.xml from modules/////////////////////////
         ArrayList modulqnames = (ArrayList) ((AxisConfigurationImpl) axisConfig).getEngadgedModules();
         for (int i = 0; i < modulqnames.size(); i++) {
@@ -383,7 +383,7 @@
                 }
                 ////////////////////////////////////////////////////////////////////////////////////
-                /////////////////// Modules refered by server.xml //////////////////////////////////
+                /////////////////// Modules refered by axis2.xml //////////////////////////////////
                 ////////////////////////////////////////////////////////////////////////////////////
                 switch (type) {
@@ -449,7 +449,7 @@
             }
             ////////////////////////////////////////////////////////////////////////////////////
-            /////////////////// Modules refered by server.xml //////////////////////////////////
+            /////////////////// Modules refered by axis2.xml //////////////////////////////////
             ////////////////////////////////////////////////////////////////////////////////////
             switch (type) {

Modified: webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/AbstractTransportSender.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/core/src/org/apache/axis/transport/AbstractTransportSender.java?rev=191799&r1=191798&r2=191799&view=diff
==============================================================================